@@ -41,6 +41,13 @@ from fc_common.version import get_runtime_version
 
 
 class Client:
+    @staticmethod
+    def booking(_):
+        fc_server = os.environ.get("FC_SERVER", "http://127.0.0.1:8600")
+        url = f"{fc_server}/booking"
+        output = requests.get(url)
+        print(output.text)
+
     @staticmethod
     def status(args):
         specified_resource = args.resource
@@ -74,9 +81,9 @@ class Client:
             table_width = len(resource)
 
         if table_width == 5:
-            table.field_names = ["Resource", "Farm", "Owner", "Comment", "Info"]
+            table.field_names = ["Resource", "Farm", "Status", "Comment", "Info"]
         else:
-            table.field_names = ["Resource", "Farm", "Owner", "Comment"]
+            table.field_names = ["Resource", "Farm", "Status", "Comment"]
 
         print(table.get_string(sortby="Resource"))
 
@@ -194,6 +201,11 @@ def main():
     )
     subparser.set_defaults(func=Client.unlock)
 
+    subparser = subparsers.add_parser(
+        "booking", aliases=("b",), help="list current booking"
+    )
+    subparser.set_defaults(func=Client.booking)
+
     args = parser.parse_args()
     args.func(args)
 
